Probabilistic Inference
======================

This module provides inference mechanisms for probabilistic models.

.. currentmodule:: torch_concepts.nn

Summary
-------

**Inference Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   ForwardInference
   DeterministicInference
   AncestralSamplingInference


Class Documentation
-------------------

.. autoclass:: ForwardInference
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: DeterministicInference
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: AncestralSamplingInference
   :members:
   :undoc-members:
   :show-inheritance:
